import { Button, Space, Modal, Switch } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/BTable";
import { useEffect, useState } from "react";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import { FormInstance } from "antd/es/form/Form";
import React from "react";
import ActiveConfig from "@/service/apiConfig/active";
import dayjs from "dayjs";
const Active = (props: Store) => {
  const { activeStore } = props;
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const [id, setId] = useState<any>(null);
  const [record, setRecord] = useState<any>(null);
  const formRef = React.useRef<FormInstance>(null);
  const [isModalOpen, setIsModalOpen] = useState(false);
  const columns: ColumnsType<UserDataType> = [
    {
      title: "活动标题",
      dataIndex: "activeName",
    },
    {
      title: "折扣",
      dataIndex: "discount",
    },
    {
      title: "活动开始时间",
      dataIndex: "startTime",
    },

    {
      title: "活动结束时间",
      dataIndex: "endTime",
    },
    {
      title: "活动状态",
      render: (any, record) => (
        <div>
          <span>{record.status ? "开启" : "关闭"}</span>
        </div>
      ),
    },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Switch
                defaultChecked
                onChange={(bools) => {
                  onChange(bools, record);
                }}
              />
              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  activeStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  editAction(record);
                }}
              >
                编辑
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const editAction = (record) => {
    record.startTime = dayjs(record.startTime, "YYYY-MM-DD");
    record.endTime = dayjs(record.endTime, "YYYY-MM-DD");
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onChange = (bools, record) => {
    activeStore.putItem(record.id, {
      status: bools,
      activeName: record.activeName,
      discount: record.discount,
      startTime: record.startTime,
      endTime: record.endTime,
    });
  };
  const defaultConfig = [
    {
      type: "input",
      label: "活动名称",
      name: "activeName",
      value: "",
      rules: [{ required: true, message: "请输入活动名称!" }],
    },

    {
      type: "input",
      label: "折扣",
      name: "discount",
      value: "",
    },
    {
      type: "Date",
      label: "活动开始时间",
      name: "startTime",
      value: "",
    },
    {
      type: "Date",
      label: "活动结束时间",
      name: "endTime",
      value: "",
    },
    {
      type: "switch",
      label: "是否开启",
      name: "status",
      value: false,
    },
  ];

  useEffect(() => {
    activeStore.getlist(ActiveConfig.LIST);
  }, [activeStore]);
  const onFinish = (values: any) => {
    values["startTime"] = values["startTime"].format("YYYY.MM.DD");
    values["endTime"] = values["endTime"].format("YYYY.MM.DD");
    if (!id) {
      activeStore.add(values);
    } else {
      activeStore.putItem(id, values);
    }
    setIsModalOpen(false);
  };
  const onFinishFailed = () => {};
  const addAction = () => {
    setProjectConfig(defaultConfig);
    setId(null);
    setRecord(null)
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);

  };
  return (
    <div className="projectContent">
      <Button className="projectContentAdd" onClick={() => addAction()}>
        添加活动
      </Button>
      <Modal
        title="活动信息"
        width={800}
        open={isModalOpen}
        onCancel={() => setIsModalOpen(false)}
        afterClose={() => formRef.current?.resetFields()}
        onOk={() => formRef.current?.submit()}
      >
        <SimpleForm
          formRef={formRef}
          createCallback={() => {
            formRef.current?.setFieldsValue(record);
          }}
          formName="card_basic"
          colProps={4}
          subBtnName="提交"
          formDatas={projectConfig}
          onFinish={onFinish}
          initialValues={true}
          onFinishFailed={onFinishFailed}
        />
      </Modal>
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <BTable
          store={activeStore}
          columns={columns}
          dataSource={activeStore.list}
        />
      </Space>
    </div>
  );
};

export default inject("activeStore")(observer(Active));
