import { Button, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/BTable";
import { useEffect, useState } from "react";
import UserConfig from "@/service/apiConfig/userConfig";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import SimpleForm from "@/components/form/simple_form";
import React from "react";

const ActiveType = (props: Store) => {
  const { activityTypeStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [userId, setId] = useState<Number | null>(null);
  const columns: ColumnsType<UserDataType> = [
    {
      title: "类型名称",
      dataIndex: "name",
    },
    {
      title: "类型描述",
      dataIndex: "desc",
    },

    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>

              <Button
                type="dashed"
                danger
                size="small"
                onClick={() => {
                  activityTypeStore.deleteItem(record.id);
                }}
              >
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    values = {
      ...values,
    };
    if (!userId) {
      activityTypeStore.add(values);
    } else {
      activityTypeStore.putItem(userId, values);
    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    activityTypeStore.getlist(UserConfig.LIST);
  }, [activityTypeStore]);
  const defaultConfig = [
    {
      type: "input",
      label: "类型名称",
      name: "name",
      value: "",
      rules: [{ required: true, message: "请输入类型名称!" }],
    },
    {
      type: "input",
      label: "类型描述",
      name: "desc",
      value: "",
      rules: [{ required: true, message: "请输入类型描述" }],
    },
  ];
  const onFinishFailed = () => {};
  const addAction = () => {
    setRecord({});
    setProjectConfig(defaultConfig);
    setId(null);
    setIsModalOpen(true);
  };
  const onCancel = () => {
    setId(null);
    setIsModalOpen(false);
  };
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Button type="default" onClick={addAction}>
          添加类型
        </Button>
        <BTable
          store={activityTypeStore}
          columns={columns}
          dataSource={activityTypeStore.list}
        />
        <Modal
          title={!userId ? "添加类型" : "编辑类型"}
          width={600}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={onCancel}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={4}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("activityTypeStore")(observer(ActiveType));
