import { Button, Space, Modal, FormInstance } from "antd";
import type { ColumnsType } from 'antd/es/table';
import { CardDataType } from "@/util/model/interface";
import { inject, observer } from "mobx-react";
import BTable from "@/components/BTable";
import SimpleForm from "@/components/form/simple_form";
import "./index.less"
import { useEffect, useState } from "react";
import React from "react";
import { useNavigate } from "react-router-dom";
import CardConfig from "@/service/apiConfig/cardConfig";
const CardPageList = (props) => {
    const { cardStore } = props;
    const [projectConfig, setProjectConfig] = useState<any>([])
    const [id, setId] = useState<any>(null)
    const [record, setRecord] = useState<any>(null)
    const formRef = React.useRef<FormInstance>(null);
    const [isModalOpen, setIsModalOpen] = useState(false);
    const navigate = useNavigate();
    const columns: ColumnsType<CardDataType> = [
        {
            title: '卡片编号',
            dataIndex: 'id',
        },
        {
            title: '名称',
            dataIndex: 'name',
        },
        {
            title: '内容',
            dataIndex: 'content',
            width: 140,
            ellipsis: true,
        },
        {
            title: '作者',
            dataIndex: 'author',
        },
        {
            title: '引文',
            dataIndex: 'extract',
        },
        {
            title: '类型',
            dataIndex: 'cardType',
            render: (cardType, record) => (
                <div>
                    {
                        cardType === "1" ? "卡片一" : (cardType === "2" ? "卡片二" : (cardType === "3" ? "卡片三" : (cardType === "4" ? "卡片四" : '暂无')))
                    }
                </div>
            ),
        },
        {
            title: '操作',
            dataIndex: 'id',
            ellipsis: {
                showTitle: false,
            },
            render: (any, record) => (
                <div>
                    <Space direction="vertical">
                        <Space wrap>
                            <Button type="dashed" size="small" onClick={() => {
                                edit(record)
                            }}>编辑</Button>
                            <Button type="dashed" size="small" onClick={() => {
                                navigate("/card/componsition/" + record.id)
                            }}>用户作文</Button>
                            <Button type="dashed" danger size="small" onClick={() => {
                                cardStore.deleteItem(record.id)
                            }}>删除</Button>
                        </Space>
                    </Space>
                </div>
            ),
        }
    ];
    const edit = (record) => {
        setProjectConfig(defaultConfig)
        setIsModalOpen(true)
        formRef.current?.setFieldsValue(record);
        setRecord(record)
        setId(record.id)
    }
    const defaultConfig = [
        {
            type: "input",
            label: "卡片名称",
            name: "name",
            value: "",
            rules: [{ required: true, message: '请输入卡片名称!' }]
        },
        {
            type: "textArea",
            label: "请输入卡片内容",
            name: "content",
            value: "",
        }, {
            type: "input",
            label: "请输入卡片作者",
            name: "author",
            value: "",
        },
        {
            type: "input",
            label: "请输入卡片引文",
            name: "extract",
            value: "",
        },
        {
            type: "select",
            label: "请选择卡片类型",
            name: "cardType",
            value: ""
        },
    ]

    const onFinish = (values: any) => {
        values.cardType = `${values.cardType}`;
        if (!id) {
            cardStore.add(values);
        } else {
            cardStore.putItem(id, values);
        }
        setIsModalOpen(false);
    };

    useEffect(() => {
        cardStore.getlist(CardConfig.CardConfig.LIST)
    }, [cardStore]);

    const onFinishFailed = () => { }
    return (
        <div className="projectContent">
            <Button className="projectContentAdd" onClick={() => {
                setProjectConfig(defaultConfig)
                setId(null)
                setIsModalOpen(true)
            }}>添加卡片</Button>
            <Modal title="卡片信息"
                width={800}
                open={isModalOpen}
                onCancel={() => setIsModalOpen(false)}
                afterClose={() => formRef.current?.resetFields()}
                onOk={() => formRef.current?.submit()}>
                <SimpleForm
                    formRef={formRef}
                    createCallback={() => {
                        formRef.current?.setFieldsValue(record);
                    }}
                    formName="card_basic"
                    colProps={4}
                    subBtnName="提交"
                    formDatas={projectConfig}
                    onFinish={onFinish}
                    initialValues={true}
                    onFinishFailed={onFinishFailed} />
            </Modal>
            <div className="editContentBox">
                <BTable columns={columns} store={cardStore} dataSource={cardStore.list} />
            </div>
        </div>
    );
};

export default inject("cardStore")(observer(CardPageList));;