import { Button, Tooltip, Image, Space, Modal, FormInstance } from "antd";
import { inject, observer } from "mobx-react";
import type { ColumnsType } from "antd/es/table";
import BTable from "@/components/BTable";
import { useEffect, useState } from "react";
import UserConfig from "@/service/apiConfig/userConfig";
import { UserDataType } from "@/model/userModel";
import { Store } from "antd/lib/form/interface";
import "./user.less";
import SimpleForm from "@/components/form/simple_form";
import React from "react";

const User = (props: Store) => {
  const { usrStore } = props;
  const [isModalOpen, setIsModalOpen] = useState<boolean>(false);
  const [projectConfig, setProjectConfig] = useState<any>([]);
  const formRef = React.useRef<FormInstance>(null);
  const [record, setRecord] = useState<any>(null);
  const [userId, setId] = useState<Number | null>(null);
  const columns: ColumnsType<UserDataType> = [
    {
      title: "用户名",
      dataIndex: "acount",
    },
    {
      title: "年龄",
      dataIndex: "age",
    },
    {
      title: "居住地",
      dataIndex: "address",
      ellipsis: {
        showTitle: false,
      },
      render: (address) => (
        <Tooltip placement="topLeft" title={address}>
          {address}
        </Tooltip>
      ),
    },
    {
      title: "性别",
      dataIndex: "sex",
      render: (sex) => <span>{sex === "0" ? "男" : "女"}</span>,
    },
    {
      title: "头像",
      dataIndex: "headImg",
      render: (headImg) => <Image src={headImg}></Image>,
    },
    {
      title: "角色",
      dataIndex: "roleName",
    },
    {
      title: "会员",
      dataIndex: "level",
      render: (level) => <span>{level === "0" ? "包年" : "超级会员"}</span>,
    },
    {
      title: "操作",
      dataIndex: "id",
      ellipsis: {
        showTitle: false,
      },
      render: (any, record) => (
        <div>
          <Space direction="vertical">
            <Space wrap>
              <Button
                type="dashed"
                size="small"
                onClick={() => {
                  edit(record);
                }}
              >
                编辑
              </Button>

              <Button type="dashed" danger size="small" onClick={() => {
                usrStore.deleteItem(record.id)
              }}>
                删除
              </Button>
            </Space>
          </Space>
        </div>
      ),
    },
  ];
  const edit = (record) => {
    record = {
      ...record,
      imageUrl: [{ url: record.imageUrl }],
    };
    setProjectConfig(defaultConfig);
    setIsModalOpen(true);
    formRef.current?.setFieldsValue(record);
    setRecord(record);
    setId(record.id);
  };
  const onFinish = (values: any) => {
    // let images = values.imageUrl.map((item) => {
    //   return item.response.data.url;
    // });

    values = {
      ...values,
      headImg:"cascas" //images.join(","),
    };
    if (!userId) {
      usrStore.add(values);
    } else {

    }
    setIsModalOpen(false);
  };
  useEffect(() => {
    usrStore.getlist(UserConfig.LIST);
  }, [usrStore]);
  const defaultConfig = [
    {
      type: "input",
      label: "用户名",
      name: "acount",
      value: "",
      rules: [{ required: true, message: "请输入人物名称!" }],
    },
    {
      type: "input",
      label: "年龄",
      name: "age",
      value: "",
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "input",
      label: "居住地",
      name: "address",
      value: "",
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "Radio",
      label: "性别",
      name: "sex",
      value: 0,
      rules: [{ required: true, message: "请输入卡片内容" }],
    },
    {
      type: "upload",
      label: "头像",
      name: "headImg",
      value: [],
      // rules: [{ required: true, message: "请上传头像" }],
    },
    {
      type: "input",
      label: "角色",
      name: "role",
      value: "",
    },
  ];
  const onFinishFailed = () => {};
  return (
    <div className="contentBox">
      <Space direction="vertical" size="middle" style={{ display: "flex" }}>
        <Button
          type="default"
          onClick={() => {
            setProjectConfig(defaultConfig);
            setId(null);
            setIsModalOpen(true);
          }}
        >
          添加用户
        </Button>
        <BTable store={usrStore} columns={columns} dataSource={usrStore.list} />
        <Modal
          title={!userId ? "添加用户" : "编辑用户"}
          width={800}
          open={isModalOpen}
          afterClose={() => formRef.current?.resetFields()}
          onOk={() => formRef.current?.submit()}
          onCancel={() => {
            setId(null);
            setIsModalOpen(false);
          }}
        >
          <SimpleForm
            formRef={formRef}
            createCallback={() => {
              formRef.current?.setFieldsValue(record);
            }}
            formName="card_basic"
            colProps={4}
            subBtnName="提交"
            formDatas={projectConfig}
            onFinish={onFinish}
            initialValues={true}
            onFinishFailed={onFinishFailed}
          />
        </Modal>
      </Space>
    </div>
  );
};

export default inject("usrStore")(observer(User));
