import baseHttp from "@/service/base";
import { Pages } from "@/util/model/interface";
import { action, makeObservable, observable, runInAction } from "mobx";
interface BaseStoreInterface<T> {
    list: Array<T>
    item: T | null | string
    getlist(url: string): any
    deleteItem(id: number): any
    putItem(url: string, param: any): any
    add(url: string, param: any): any
    total: number
    page: Pages
    setPages(pages: Pages): any
}

class BaseStore<B> implements BaseStoreInterface<B> {
    urlConfig: { DELETE: string; ADD: string; EDIT: string; LIST: string; }
    constructor(urlConfig) {
        makeObservable(this, {
            getlist: action,
            deleteItem: action,
            putItem: action,
            setPages: action,
            list: observable,
            item: observable,
            total: observable,
            page: observable,
            add: action
        })
        this.urlConfig = urlConfig;
    }
    // 删除
    async deleteItem(id: number) {
        await baseHttp.delete(this.urlConfig.DELETE + "/" + id, {})
        this.getlist()
    }
    // 分页
    setPages(params: Pages) {
        this.page = params
        this.getlist()
    }
    // 添加
    async add(param: any) {
        await baseHttp.post(this.urlConfig.ADD, param)
        this.getlist();
    }

    // 更新
    async putItem(id: string, param: any) {
        await baseHttp.put(this.urlConfig.EDIT + "/" + id, param)
        this.getlist()
    }

    // 获取列表
    async getlist() {
        let res = await baseHttp.get(this.urlConfig.LIST, {
            pageIndex: this.page?.PageNum ?? 1,
            pageSize: this.page?.PageSize ?? 20,
            isSelf: 0
        });
        console.log(this.page?.PageNum)
        let data: Array<B> = []
        if (!res.data.records) {
            runInAction(() => {
                this.list = data;
            })
            return;
        }
        for (let i = 0; i < res.data.records.length; i++) {
            data.push({
                key: res.data.records[i].id,
                ...res.data.records[i]
            })
        }
        runInAction(() => {
            this.list = data;
            this.total = res.data.total | res.data.totals
        })
    }
    list!: Array<B>;
    item!: B | null | string
    total!: number;
    page!: Pages;
}

export default BaseStore