import { action, makeAutoObservable, observable } from "mobx";
import baseHttp from "@/service/base";
import { CardDataType, Pages, ComponsitionDataType } from "@/util/model/interface";
import componsitionConfig from "@/service/apiConfig/componsitionConfig";
class ComponSitionStore {
    datalist: ComponsitionDataType[] = [];
    total: number | null | undefined;
    _pages: Pages = {
        PageNum: 1,
        PageSize: 20
    }
    constructor() {
        makeAutoObservable(this, {
            list: action,
            delete: action,
            datalist: observable,
            _pages: observable,
            setPages: action
        })
    }
    setlist = (arrlist: ComponsitionDataType[]) => {
        this.datalist = arrlist
    }
    setPages = (page: Pages) => {
        this._pages = page
    }
    async add(param: CardDataType) {
        await baseHttp.post(componsitionConfig.ADD, param)
    }
    async edit(param: CardDataType, id: any) {
        await baseHttp.put(componsitionConfig.EDIT + "/" + id, param)
    }

    async list(id:string) {
        let arr = await baseHttp.get(componsitionConfig.LIST + `/${id}`, {
            pageIndex: this._pages.PageNum,
            pageSize: this._pages.PageSize,
        })
        let listdata = arr.data.records;
        if (!listdata) this.datalist = []
        this.total = arr.data.total
        let arrs: ComponsitionDataType[] = [];
        for (let index = 0; index < listdata.length; index++) {
            arrs.push({
                key: listdata[index].id,
                ...listdata[index]
            })
        }
        this.datalist = arrs;
    }

    async delete(id: number) {
        await baseHttp.delete(componsitionConfig.DELETE + "/" + id, {})
    }
}

export default new ComponSitionStore();