import UserConfig from "@/service/apiConfig/userConfig";
import { action, computed, makeObservable, observable } from "mobx";
// 用户信息
import baseHttp from "@/service/base";
import BaseStore from "../baseStore";
import { UserDataType, UserInfos } from "@/model/userModel";

class UserStore extends BaseStore<UserDataType> {
    _userinfo: UserInfos = {}; // 用户信息
    constructor() {
        super(UserConfig)
        makeObservable(this, {
            logOut: action,
            login: action,
            _userinfo: observable,
            userInfo: computed,
        })
    }
    get userInfo(): UserInfos {
        if (!this._userinfo.token) {
            let token = window.localStorage.getItem("token")
            this._userinfo.token = token;
        }
        return this._userinfo;
    }
    logOut() {
        this._userinfo.token = "";
        window.localStorage.clear();
        this.item = "";
    }
    async login(params: UserInfos) {
        let data = await baseHttp.forms(UserConfig.LOGINURI, {
            acount: params.userName,
            password: params.passWord,
        })
        this._userinfo = {
            userName: data.data.name,
            token: data.data.token,
            headerImag: data.data.headerImag,
            role: "",
            passWord: data.data.password,
        };
        window.localStorage.setItem("token", data.data.token ?? "");
    }
}

export default new UserStore();